package Qt::Gui::QCommandLinkButton;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QCommandLinkButton
# file     : QtGui/qcommandlinkbutton.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QPushButton/;
#our @ISA = qw/Qt::Gui::QPushButton/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QCommandLinkButton

=head1 PUBLIC METHODS

=over

=item   QCommandLinkButton(QWidget * parent)

=item   QCommandLinkButton(QWidget * parent = 0)

=item   QCommandLinkButton(const QString & text, QWidget * parent)

=item   QCommandLinkButton(const QString & text, QWidget * parent = 0)

=item   QCommandLinkButton(const QString & text, const QString & description, QWidget * parent)

=item   QCommandLinkButton(const QString & text, const QString & description, QWidget * parent = 0)

=item  QString description()

=item  void setDescription(const QString & description)


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
